close all
% caoutchouc
E = 21e5; nu = 0.45; %nu = 0.28; 
mu= E/(2*(1+nu));
lambda = E*nu/((1+nu)*(1-2*nu));
L=20;
N=7;
%  

fprintf('------------------------------------------------------\n'); 
fprintf('      2D elasticity BVP on [0,%g]x[-1,1]\n',L);
fprintf('         on transform hypercube mesh\n\n');
fprintf('             -div(sigma(u)) = f \n');
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [1]\n');
fprintf('       u_1 = u_2 = 0 on [1],\n');
fprintf('   * Neumann on [2,3,4]\n');
fprintf('       sigma(u).n = 0 on [2,3,4]\n');
fprintf(' with f=(0,-1)^t, lambda=%g, mu=%g\n',lambda,mu);
fprintf('------------------------------------------------------\n'); 
dim=2;

fprintf('1. Building the mesh using HyperCube function\n');
Th=fc_simesh.HyperCube(dim,[10*N,N],'trans',@(q) [20*q(1,:);-1+2*q(2,:)]);
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());
fprintf('2.a Setting 2D elasticity BVP\n');
%Hop=Hoperator.StiffElas(dim,lam,mu);
gamma=lambda+2*mu;
Hop=Hoperator(dim,dim,dim);
Hop.set(1,1,Loperator(dim,dim,{gamma,[];[],mu},[],[],[])); 
Hop.set(1,2,Loperator(dim,dim,{[],lambda;mu,[]},[],[],[]));
Hop.set(2,1,Loperator(dim,dim,{[],mu;lambda,[]},[],[],[]));
Hop.set(2,2,Loperator(dim,dim,{mu,[];[],gamma},[],[],[]));
pde=PDEelt(Hop,{0,-1});
bvp=BVP(Th,pde);
bvp.setDirichlet(1,0.,1:2);
fprintf('2.b Solving 2D elasticity BVP\n')
U=bvp.solve('split',true);

fprintf('3. Graphic representations\n');
figure(1)
Th.plotmesh('color',0.85*[1,1,1])
hold on,axis image,axis off
Th.plotmesh('d',1,'LineWidth',1.5,'legend',true)
scale=50;
idx=Th.find(2); % for hypercube, only 1 elt
sTh=Th.sTh{idx}.copy();
sTh.q=sTh.q+scale*[U{1}';U{2}'];
figure(2)
Th.plotmesh()
hold on
sTh.plotmesh('color','r')
axis off, axis image

